#!/usr/bin/python
#
# Copyright 2010, Red Hat, Inc.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# Author: Chris Lumens <clumens@redhat.com>

from meh.handler import *
from meh.dump import *

def initExceptionHandling(intf, obj, cb):
    from pyanaconda import isys

    conf = Config(programName="anaconda",
                  programVersion=isys.getAnacondaVersion(),
                  fileList=[])
    handler = TestExceptionHandler(conf, intf, ReverseExceptionDump)
    handler.install(obj)

    # We'll need this later to connect to the results server.
    handler.reportCB = cb
    return conf

class TestExceptionHandler(ExceptionHandler):
    def __init__(self, *args, **kwargs):
        ExceptionHandler.__init__(self, *args, **kwargs)
        self.reportCB = None

    def handleException(self, (ty, value, tb), obj):
        # Restore original exception handler.
        sys.excepthook = sys.__excepthook__

        self.preWriteHook((ty, value, tb), obj)

        # Save the exception to the filesystem first.
        self.exn = self.exnClass((ty, value, tb), self.conf)
        (fd, self.exnFile) = self.openFile()
        text = self.exn.write(obj, fd)
        fd.close()

        self.postWriteHook((ty, value, tb), obj)
        self.reportCB()
